from setuptools import setup

setup(name='algovent_utils',
      version='0.1',
      description='utils to support django-algovent framework',
      url='http://github.com/storborg/funniest',
      author='Naveen Bollimpalli',
      author_email='naveenbollimpalli@gmail.com',
      license='MIT',
      packages=['algovent_utils'],
      zip_safe=False)